<?php
namespace bwdahAnimatedHeading;

use bwdahAnimatedHeading\PageSettings\Page_Settings;
define( "BWDAH_ASFSK_ASSETS_PUBLIC_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/public" );
define( "BWDAH_ASFSK_ASSETS_ADMIN_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/admin" );
class ClassBWDAHAnimatedHeading {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function bwdah_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'bwdah_admin_editor_scripts_as_a_module' ], 10, 2 );
	}

	public function bwdah_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'bwdah_the_animated_heading_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}
		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/bwdah-animated-heading.php' );

	}

	public function bwdah_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\BWDAHAnimatedHeadingWidget() );
	}

	private function add_page_settings_controls() {
		require_once( __DIR__ . '/page-settings/animated-heading-manager.php' );
		new Page_Settings();
	}


	// Register Category
	function bwdah_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'bwdah-animated-heading-category',
			[
				'title' => esc_html__( 'BWD Animated Heading', 'bwdah-animated-heading' ),
				'icon' => 'eicon-person',
			]
		);
	}

	public function bwdah_all_assets_for_the_public(){
		$all_css_js_file = array(
            'bwdah_animated_heading_all_main_css' => array('bwdah_path_define'=>BWDAH_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/all.min.css'),

            'bwdah_animated_heading_style_css' => array('bwdah_path_define'=>BWDAH_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/style.css'),

            'bwdah_animated_heading_bootstrap_css' => array('bwdah_path_define'=>BWDAH_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/bs/bootstrap.min.css'),

            'bwdah_animated_heading_custom_js' => array('bwdah_path_define'=>BWDAH_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/js/custom.js'),

            'bwdah_animated_heading_bootstrap_js' => array('bwdah_path_define'=>BWDAH_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/js/bs/bootstrap.min.js'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdah_path_define'], null, '1.0', 'all');
            wp_enqueue_script( $handle, $fileinfo['bwdah_path_define'], ['jquery'], '1.0', true);
        }
	}

	public function bwdah_all_assets_for_elementor_editor_admin(){
		$all_css_js_file = array(
            'bwdah_animated_heading_admin_icon_css' => array('bwdah_path_admin_define'=>BWDAH_ASFSK_ASSETS_ADMIN_DIR_FILE . '/icon.css'),
        );

        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdah_path_admin_define'], null, '1.0', 'all');
        }
	}

	public function __construct() {
		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'bwdah_all_assets_for_the_public']);

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'bwdah_all_assets_for_elementor_editor_admin']);
		
		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'bwdah_add_elementor_widget_categories' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'bwdah_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'bwdah_admin_editor_scripts' ] );
		
		$this->add_page_settings_controls();
	}
}

// Instantiate Plugin Class
ClassBWDAHAnimatedHeading::instance();